==> whmcs-8.8.0-release.1.zip: resources/views/marketconnect/services/sitelock/index.php <==
<?php //ICB0 72:0 81:1050                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.8.0 (8.8.0-release.1)                                      *
// * BuildId:06fc63b.326                                                  *
// * Build Date:20 Sep 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPqrO9rIRffkR4kkoTm/ErJ6WuegeqnDFVjAqePeBbFe/YWXGbFsAB0JN9snhgOfXA3sF/JUj
RaluirgZO5GzWOdJxzgPWXv+IgwcY7h6lNqGgkM7HVPHH6P/2ZKk4I4TEE8xV//sJCb3V7l9tPf9
bzTQkly1P92C0Onb5HK1gnnHtmF607u5KUz9PXzMdRVvC/rT1CvdWOYV7DqdaAYUw4cqQScrnh78
F/a59jgV19Au5B/fg27kPbge7XsEZVgbBDzom24DU1v5+JisINJaaXFwFMgSigbrE/gMBu/tP3eI
aHEDWsvYbxjCrJ6aw9vg5e8CXsl/S5cDV4VsS7CUtZlPYC+/bTkyugqlJp+tI3sdTKdLpnHFkDiT
3AdfBATXe81YSFtCWfaTZQ6WtMn5hJbhedLJ2tVs4MEVfuJdxXBDXuckY7Ot6+xG5gqDu/jO78R0
PAB9uqJNGHcPjyRwSeho8KRnpUsSKCiaHncUt0kSyDl3Fuwi1iByYth4lT+SLIW4Z0WIRb16KuXM
JHq/oPuDcytEvZNHT5AbvZ7E3h6hFbeNEM7Zp17ct7zOk/Uf+zOOH+nKOEy9BolaxQeHf5jTVPwu
IYjfb08sbG/0ujW30ShaEqfLki0hnsiPksaDpFSiV1cniMyBhnOhJdOROWZuZfyDCHAbAKIrQDSG
ykeVmoVuZBiz0+wHEZqLB9ZHm/A46foS1kAe+SSSzadrCLZRdRmXTxJRYObPyg9Fr1Dk23UoTAJr
/GDYBcZDoQtrJFJAdFfeshL9Pd5+f/5BNFjqySn62F+T2q3zcI6VqHKquYmngr9IJrygjQDcPWKa
GgVYv4OT7QIjBAQQL19z6gTupDvU89G/HvZHqdZ60/K/x6iwAm5jtmbzMSYAlGFMI4i==
HR+cPuN+0ZqHKlSod42N7heUDLDXefThK8TnVkbVOKd6/MFLcK7cSbQO+QSJ6qewCnCBShHZG+Yw
QyoJnexLWmF7smHqMKgS5G96CJBxRFFIt6XZzV/65EutyHPjTca+Je1xGxQY7r9oA3eVE9YBktep
aAuuU/I1VawKWs6oQ1NN++ru5LAmKXk0kQYrDsRLYCjFbMlFyfqvpXa+Wv0TCSyZ7o76RdjlJQ8o
cW581JH4mqOlQtfLS9dOtEkwr5+WfFixkaFLhgfaqrHzLDf8CzWAHBfp8edVCG7R0e5C1dG77BbF
E2lmPce6o6UJREGljWGXMpSNsqaQlmYQ8yxgX78b3gceVVTOLMI/vBeDeV/A6qc9k0haXQoxZrZi
SRBQGB1BZxk2y8gamcquMzrIOZbIPDK/TPECO2Br6c2/xgLBsuTe0npBWjom8sjWI1jCcNZFua6N
uaXydRewkRCm2P3Izs4ochMYYLpaWuhfcl7XYOLjkG7OfTOB0cS2HUGYLGieuoeUcysd/gpIgQ63
pckPRvBEvbKhgQ0FwWRpks07dKRaHTFZn4nxcqRNGDS4onfGX6RO6gAP2NFKIoBso4jcC4F8z43D
lxyaV6sB8aoRJmrkSaZ3n4dM3WC6EVvy2qM5CVOfaSUnSIC7AYkNSUD9+66QQz1e4OnbPc5bAVea
5R1tsjjOOL2Qhm9gFIBPEh/IHb2tyHmvV+vC91JXHz+fIGCk4GP63Jj6u+UADEpQyVsYivOHDuG1
JIO2+oXO62DAdxvWGd8xsPuG3KjihcfIJzUgjngoSiQnVoNPXkSjFv+/+QO24Q/xd7jeUEWxIMYJ
QUEAylQjZPRVv7vPpl6kSsUeCeLl6JDGKTYIMxhBj6/d8XCkhnsPjLIY+haMAwBRqIGh

==> whmcs-8.10.0-release.1.zip: resources/views/marketconnect/services/sitelock/index.php <==
<?php //ICB0 72:0 81:1050                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.10.0 (8.10.0-release.1)                                    *
// * BuildId:dc9095d.372                                                  *
// * Build Date:23 Apr 2024                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPrATsULdO2BA3YvCnWFfz18M0qFqw0P1SUGureOrXS3JTHhEqhepM3kal9ileaaT1JXDVWrJ
AU3Q0PyzqAZZdw4I5L+7vXGNCY3WbomNAFhYGtRyDdpXSpUi9if/zXrN+2MRcIJO4APuzXbyAxV0
nVDypde0Qdt/OBM/36xP1wMih38UqnDFzsr3AufOMyCBHB89cQxI1ECzDhPR+f4koP98gXya4OJH
mb/vmOij90iPOV/SoJ/3I/wkIzIZgtqdFu2AGkdoUVGJXlodbGRjIyfQfjMW1G1cL8EmmtgBXY6W
Oc5OoMXkcKxULuvXBxq0W7H2xUaU/+bqY+7tPH5+UiYFHFg8JlhSAqygBxB/IzD2nLTUv0u+cjb2
fclM7asOWoDczJT4pw40yDvN2sHbDkCt/D1mrJZlyOEJj7GcFYVXSCpubXmVuJlBBf+100y/Kfkr
LCVmO70hYLZaAbIha1o1fkeIG+uU3lr38H5kfa8F5NLHHkmpiWCVkY2xM6INEYlPsg1CAw7Cnqqa
d4093+PAztVEsYA78rr6acOn9fzPUgwg97yN87lGtJAzXiJJsxxVhTmUFYLm/VPHFjZoYcjbnS0f
ZN3CrsGB0EFCqlywQGFsVX7/qiioGVTYDJROnQ+e05DKodGYJ9qSpty9eCI+9ScMWGCCE4vKxf10
uIei90BYWwehbYGc8V8Snfi59kcLAg2Ad8SECwyucyA1+uYzcwB8z8cXRmouvjqe9Bx+pzRHViqI
CMUJYdxxCHhEiBp7cssB6i9HMl2Q2nNtO+rO9C/H6PrgPtVxRxoBQU7cJ/+eawHdbLdkr9tSY1QJ
7LPcUPgH+Lfcs8qPWbFnzNdrsyWN/71Umfl3pmam1g9DTC2pTmwuYonqMYai7gxZrAC3=
HR+cPpTJS/YTe4VmAEtcsql78qgu1MWY4o37Je38VWDTmboZt2hK1t+6uLBWrBDULZ/r/3i3U1Oe
qwK/3I13Hh+ob0SgH4hH8rESnHNJ2R+3gZ6NIHpGyoMrpncjThYlcFt8wM49Wk6y1p6kcxoT6D5p
Corl/MIHvIkyj8RreiHohE1CP8ueOs4vIL9ybC2QKTm34qyq1HgPP4zGmxx+SpiVoZEisDP6YV7H
1mCLW05SI9NZ41GbhexjQQYJaGCLCoPMV2HcONxaNE3xAzE3FX3IRXFfLEqrneqdegJgjfKXPj4I
3qqtQpiaac3KVrN7nu7R1U2T8VyPhrS64JehWOCtoSd7UWCT3gYOsrExQ18k9hz2zwXmLYJv4yNQ
AuKT9znvey3it4BPZzJbfUU0ZNMgs97FasHE0ViKP0Axfm+xxZhhiO2dzc6togHB/lPOYBieLxpN
yKYJ5vkZtvCP9JC7Ix0uXkKVsgWLS39cQq0OAP5o0LjFgl7aRpyX70MrbAFaMtivEAyCdKJb1T/E
hYEtzqE8XzM80BPHLrbXTdNOJE1ok6/WkGnKSFOJQhjCCjxoFUBaubFOn5bl37XN3ITXf4I5Tno2
wF6mz4Z2HlnM7LIGtaboqZeZDz5q0yfozPniSDWB2FU6REYh1b3OhRcyDzQDakP4efGcjK/4dp6q
lzt6opVlhkh+USHbJhj33lABDVGTOe5YjgfGCcwFqglavXMoHsTK+nJPtmYNcjW+yC/XoS1vqfEI
dRhstnkBWoteg0bVHUzt/EcRmwTBJmaaPt35R37LbeoHoy5Pg9FNuY0qrKImnI/0U2pMYcKxt86u
07bsGw7IgOClCR/dfjH/KtHm7gsUFoVQ2Y4SAh9tJkScOjd0vic4AgLcsRiN
